// Copyright 2023 Azul Systems, Inc.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are met:
//
// 1. Redistributions of source code must retain the above copyright notice,
// this list of conditions and the following disclaimer.
//
// 2. Redistributions in binary form must reproduce the above copyright notice,
// this list of conditions and the following disclaimer in the documentation
// and/or other materials provided with the distribution.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
// AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
// IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
// ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
// LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
// CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
// SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
// INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
// CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
// ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
// POSSIBILITY OF SUCH DAMAGE.

package jdk.internal.crac;

/**
 * Some classes that could use logging are initialized early during the boot
 * and keeping the logger in static final field there could cause problems
 * (e.g. recursion when service-loading logger implementation).
 * Therefore, we isolate the logger into a subclass and initialize lazily.
 */
public class LoggerContainer {
    public static final System.Logger logger = System.getLogger("jdk.crac");

    public static void info(String msg) {
        logger.log(System.Logger.Level.INFO, msg);
    }

    public static void debug(String fmt, Object... params) {
        logger.log(System.Logger.Level.DEBUG, fmt, params);
    }

    private LoggerContainer() {}

    public static void warn(String fmt, Object... params) {
        logger.log(System.Logger.Level.WARNING, fmt, params);
    }

    public static void error(String msg) {
        logger.log(System.Logger.Level.ERROR, msg);
    }

    public static void error(String fmt, Object... params) {
        logger.log(System.Logger.Level.ERROR, fmt, params);
    }

    public static void error(Throwable t, String msg) {
        logger.log(System.Logger.Level.ERROR, msg, t);
    }
}
